package com.jiuqi.grid;

import com.jiuqi.util.StreamException;
import com.jiuqi.util.Stream;
import java.io.Serializable;

public class GridFontNames implements Serializable, Cloneable
{
    private int count;
    private String[] names;
    
    public GridFontNames(final int maxCount) {
        this.names = new String[maxCount];
        this.count = 0;
    }
    
    public int count() {
        return this.count;
    }
    
    public int addFont(final String fontName) {
        for (int i = 0; i < this.count; ++i) {
            if (this.names[i].equals(fontName)) {
                return i;
            }
        }
        if (this.count < this.names.length) {
            this.names[this.count] = fontName;
            ++this.count;
            return this.count - 1;
        }
        this.names[0] = fontName;
        return 0;
    }
    
    public String getFont(final int index) {
        return (index >= 0 && index < this.count) ? this.names[index] : "";
    }
    
    public void setFont(final int index, final String value) {
        if (index >= 0 && index < this.count) {
            this.names[index] = value;
        }
    }
    
    public int indexOfFont(final String fontName) {
        for (int i = 0; i < this.count; ++i) {
            if (this.names[i].equals(fontName)) {
                return i;
            }
        }
        return -1;
    }
    
    public void loadFromStream(final Stream stream) throws StreamException {
        this.count = stream.readInt();
        for (int i = 0; i < this.count; ++i) {
            final byte ll = stream.read();
            final int l = (ll < 0) ? (127 + Math.abs(ll)) : ll;
            this.names[i] = stream.readString(l);
        }
    }
    
    public void saveToStream(final Stream stream) throws StreamException {
        stream.writeInt(this.count);
        for (int i = 0; i < this.count; ++i) {
            final byte[] name = this.names[i].getBytes();
            stream.write((byte)name.length);
            stream.writeBuffer(name, 0, name.length);
        }
    }
    
    public Object clone() {
        try {
            final GridFontNames result = (GridFontNames)super.clone();
            result.names = new String[this.names.length];
            for (int i = 0; i < this.names.length; ++i) {
                result.names[i] = this.names[i];
            }
            return result;
        }
        catch (final CloneNotSupportedException ex) {
            return null;
        }
    }
}
